==> keras3_0.1.0.tar.gz: keras3/R/module-tethers.R <==
#' @title keras.activations
#' @name keras.activations
#' @tether keras.activations
#' @noRd
NULL


#' @title keras.applications
#' @name keras.applications
#' @tether keras.applications
#' @noRd
NULL


#' @title keras.backend
#' @name keras.backend
#' @tether keras.backend
#' @noRd
NULL


#' @title keras.callbacks
#' @name keras.callbacks
#' @tether keras.callbacks
#' @noRd
NULL


#' @title keras.config
#' @name keras.config
#' @tether keras.config
#' @noRd
NULL


#' @title keras.constraints
#' @name keras.constraints
#' @tether keras.constraints
#' @noRd
NULL


#' @title keras.datasets
#' @name keras.datasets
#' @tether keras.datasets
#' @noRd
NULL


#' @title keras.distribution
#' @name keras.distribution
#' @tether keras.distribution
#' @noRd
NULL


#' @title keras.export
#' @name keras.export
#' @tether keras.export
#' @noRd
NULL


#' @title keras.initializers
#' @name keras.initializers
#' @tether keras.initializers
#' @noRd
NULL


#' @title keras.layers
#' @name keras.layers
#' @tether keras.layers
#' @noRd
NULL


#' @title keras.legacy.saving
#' @name keras.legacy.saving
#' @tether keras.legacy.saving
#' @noRd
NULL


#' @title keras.legacy
#' @name keras.legacy
#' @tether keras.legacy
#' @noRd
NULL


#' @title keras.losses
#' @name keras.losses
#' @tether keras.losses
#' @noRd
NULL


#' @title keras.metrics
#' @name keras.metrics
#' @tether keras.metrics
#' @noRd
NULL


#' @title keras.mixed_precision
#' @name keras.mixed_precision
#' @tether keras.mixed_precision
#' @noRd
NULL


#' @title keras.models
#' @name keras.models
#' @tether keras.models
#' @noRd
NULL


#' @title keras.ops.image
#' @name keras.ops.image
#' @tether keras.ops.image
#' @noRd
NULL


#' @title keras.ops.nn
#' @name keras.ops.nn
#' @tether keras.ops.nn
#' @noRd
NULL


#' @title keras.ops.numpy
#' @name keras.ops.numpy
#' @tether keras.ops.numpy
#' @noRd
NULL


#' @title keras.ops
#' @name keras.ops
#' @tether keras.ops
#' @noRd
NULL


#' @title keras.optimizers.legacy
#' @name keras.optimizers.legacy
#' @tether keras.optimizers.legacy
#' @noRd
NULL


#' @title keras.optimizers.schedules
#' @name keras.optimizers.schedules
#' @tether keras.optimizers.schedules
#' @noRd
NULL


#' @title keras.optimizers
#' @name keras.optimizers
#' @tether keras.optimizers
#' @noRd
NULL


#' @title keras.preprocessing.image
#' @name keras.preprocessing.image
#' @tether keras.preprocessing.image
#' @noRd
NULL


#' @title keras.preprocessing.sequence
#' @name keras.preprocessing.sequence
#' @tether keras.preprocessing.sequence
#' @noRd
NULL


#' @title keras.preprocessing
#' @name keras.preprocessing
#' @tether keras.preprocessing
#' @noRd
NULL


#' @title keras.random
#' @name keras.random
#' @tether keras.random
#' @noRd
NULL


#' @title keras.regularizers
#' @name keras.regularizers
#' @tether keras.regularizers
#' @noRd
NULL


#' @title keras.saving
#' @name keras.saving
#' @tether keras.saving
#' @noRd
NULL


#' @title keras.utils.legacy
#' @name keras.utils.legacy
#' @tether keras.utils.legacy
#' @noRd
NULL


#' @title keras.utils
#' @name keras.utils
#' @tether keras.utils
#' @noRd
NULL


#' @title keras
#' @name keras
#' @tether keras
#' @noRd
NULL

==> keras3_1.2.0.tar.gz: keras3/R/module-tethers.R <==
#' @title keras.activations
#' @name keras.activations
#' @tether keras.activations
#' @noRd
NULL


#' @title keras.applications
#' @name keras.applications
#' @tether keras.applications
#' @noRd
NULL


#' @title keras.backend
#' @name keras.backend
#' @tether keras.backend
#' @noRd
NULL


#' @title keras.callbacks
#' @name keras.callbacks
#' @tether keras.callbacks
#' @noRd
NULL


#' @title keras.config
#' @name keras.config
#' @tether keras.config
#' @noRd
NULL


#' @title keras.constraints
#' @name keras.constraints
#' @tether keras.constraints
#' @noRd
NULL


#' @title keras.datasets
#' @name keras.datasets
#' @tether keras.datasets
#' @noRd
NULL


#' @title keras.distribution
#' @name keras.distribution
#' @tether keras.distribution
#' @noRd
NULL


#' @title keras.export
#' @name keras.export
#' @tether keras.export
#' @noRd
NULL


#' @title keras.initializers
#' @name keras.initializers
#' @tether keras.initializers
#' @noRd
NULL


#' @title keras.layers
#' @name keras.layers
#' @tether keras.layers
#' @noRd
NULL


#' @title keras.legacy.saving
#' @name keras.legacy.saving
#' @tether keras.legacy.saving
#' @noRd
NULL


#' @title keras.legacy
#' @name keras.legacy
#' @tether keras.legacy
#' @noRd
NULL


#' @title keras.losses
#' @name keras.losses
#' @tether keras.losses
#' @noRd
NULL


#' @title keras.metrics
#' @name keras.metrics
#' @tether keras.metrics
#' @noRd
NULL


#' @title keras.mixed_precision
#' @name keras.mixed_precision
#' @tether keras.mixed_precision
#' @noRd
NULL


#' @title keras.models
#' @name keras.models
#' @tether keras.models
#' @noRd
NULL


#' @title keras.ops.image
#' @name keras.ops.image
#' @tether keras.ops.image
#' @noRd
NULL


#' @title keras.ops.nn
#' @name keras.ops.nn
#' @tether keras.ops.nn
#' @noRd
NULL


#' @title keras.ops.numpy
#' @name keras.ops.numpy
#' @tether keras.ops.numpy
#' @noRd
NULL


#' @title keras.ops
#' @name keras.ops
#' @tether keras.ops
#' @noRd
NULL


#' @title keras.optimizers.legacy
#' @name keras.optimizers.legacy
#' @tether keras.optimizers.legacy
#' @noRd
NULL


#' @title keras.optimizers.schedules
#' @name keras.optimizers.schedules
#' @tether keras.optimizers.schedules
#' @noRd
NULL


#' @title keras.optimizers
#' @name keras.optimizers
#' @tether keras.optimizers
#' @noRd
NULL


#' @title keras.preprocessing.image
#' @name keras.preprocessing.image
#' @tether keras.preprocessing.image
#' @noRd
NULL


#' @title keras.preprocessing.sequence
#' @name keras.preprocessing.sequence
#' @tether keras.preprocessing.sequence
#' @noRd
NULL


#' @title keras.preprocessing
#' @name keras.preprocessing
#' @tether keras.preprocessing
#' @noRd
NULL


#' @title keras.random
#' @name keras.random
#' @tether keras.random
#' @noRd
NULL


#' @title keras.regularizers
#' @name keras.regularizers
#' @tether keras.regularizers
#' @noRd
NULL


#' @title keras.saving
#' @name keras.saving
#' @tether keras.saving
#' @noRd
NULL


#' @title keras.utils.legacy
#' @name keras.utils.legacy
#' @tether keras.utils.legacy
#' @noRd
NULL


#' @title keras.utils
#' @name keras.utils
#' @tether keras.utils
#' @noRd
NULL


#' @title keras
#' @name keras
#' @tether keras
#' @noRd
NULL


# tether functions that aren't currently exported, but
# we might want to currently export in the future.

# Seems like it's only useful for dynamic switching
# "int" to int32 or int64 depending on backend.
#' @title standardize_dtype
#' @name standardize_dtype
#' @tether keras.utils.standardize_dtype
#' @noRd
NULL

# These submodules seem not that useful for R users, but keep an eye on them w/ tethers.
#' @title keras.tree
#' @name keras.tree
#' @tether keras.tree
#' @noRd
NULL

#' @title keras.quantizers
#' @name keras.quantizers
#' @tether keras.quantizers
#' @noRd
NULL

#' @title keras.dtype_policies
#' @name keras.dtype_policies
#' @tether keras.dtype_policies
#' @noRd
NULL
